jQuery(document).ready(function(e){var t=e("#gdpr-consent-banner form").data("json-url");e.ajax({type:"GET",url:t,headers:{"Cache-Control":"no-cache"}}).done(function(t){0==t.length?e("#gdpr-consent-banner").remove():e("#gdpr-consent-banner").show()});function r(){e.ajax({type:"GET",url:"@@get_analytics",headers:{"Cache-Control":"no-cache"}}).done(function(t){e("div#plone-analytics").html(t)}),0<e(".gdpr-iframe").length&&e.ajax({type:"GET",url:"@@allow_iframes",headers:{"Cache-Control":"no-cache"}}).done(function(t){1==t&&(e(".gdpr-iframe-message").hide(),e(".gdpr-iframe").each(function(){e(this).attr("src",e(this).attr("gdpr-src")),e(this).attr("gdpr-height")?e(this).attr("height",e(this).attr("gdpr-height")):e(this).removeAttr("height"),e(this).attr("gdpr-width")?e(this).attr("width",e(this).attr("gdpr-width")):e(this).removeAttr("width")}))})}window.Faceted&&jQuery(Faceted.Events).bind(Faceted.Events.AJAX_QUERY_SUCCESS,function(){r()}),r()}),define("/Users/laurent/instances/buildout.smartweb/src/imio.smartweb.common/src/imio/smartweb/common/browser/static/view.js",function(){});
//# sourceMappingURL=smartweb-common-view-compiled.js.map