jQuery(document).ready(function(i){i("form.tabbed-form-with-toggle fieldset:first legend").hide(),i("form.tabbed-form-with-toggle fieldset:first legend").addClass("expanded"),i("form.tabbed-form-with-toggle fieldset:not(:first) legend").siblings().hide(),i("form.tabbed-form-with-toggle fieldset:not(:first) legend").addClass("collapsed"),i("form.tabbed-form-with-toggle fieldset:not(:first) legend").click(function(){var e=i(this),t=!1;i(this).siblings().slideToggle("fast",function(){t||(e.toggleClass("collapsed"),e.toggleClass("expanded"),t=!0)})})}),define("/Users/laurent/instances/buildout.directory/src/imio.smartweb.common/src/imio/smartweb/common/browser/static/edit.js",function(){});
//# sourceMappingURL=smartweb-common-edit-compiled.js.map